@@ -22,7 +22,7 @@ def detect_type(types):
         types = string_join('\\"', types, '\\"')
         types = types.replace("String", "asd")
     elif "Boolean" in types:
-        types = types.replace("Boolean", "TRUE")
+        types = types.replace("Boolean", "true")
     elif "Float" in types:
         types = types.replace("Float", "0.5")
     elif "Int" in types:
@@ -353,34 +353,34 @@ def generate(argument, custom=False, qpath="%s/%s", detect=True, green_print=lam
     index = 0
     for qname in q_name:
         print(" |  %s" % str(qname))
-        query_write(qpath, "query", qname, "{\"query\":\"query %s {%s" % (qname, qname), "w")
+        query_write(qpath, "query", qname, "{\"query\":\"query {\\n\\t%s" % qname, "w")
         if len(q_args_name[index]) != 0:
-            query_write(qpath, "query", qname, "(", "a")
+            arguments = []
             for argsname in q_args_name[index]:
                 # POP out of the list empty values
                 if argsname != "":
                     # if detect type (-d param) is enabled, retrieve placeholders according to arg type
                     if detect:
-                        query_write(qpath, "query", qname,
-                                   "%s:%s " % (argsname, detect_type(q_args_type.pop())), "a")
+                        arguments.append("%s:%s" % (argsname, detect_type(q_args_type.pop())))
                     else:
-                        query_write(qpath, "query", qname,
-                                   "%s:%s " % (argsname, q_args_type.pop()), "a")
+                        arguments.append("%s:%s" % (argsname, q_args_type.pop()))
                 else:
                     q_args_type.pop()
             # Query name
-            query_write(qpath, "query", qname, ")", "a")
-        query_write(qpath, "query", qname, "{", "a")
+            query_write(qpath, "query", qname, "(%s)" % " ".join(arguments), "a")
         # Query fields
         f_index = 0
+        fields_str = ""
         for fieldsnames in fields_names:
             if q_type[index] in fields_names[f_index][0]:
                 for items in fields_names[f_index][1:]:
-                    query_write(qpath, "query", qname, "\\n\\t%s " % items, "a")
+                    fields_str += "\\n\\t\\t%s " % items
                 break
             f_index += 1
         # Close query
-        query_write(qpath, "query", qname, "\\n}}\"}", "a")
+        if fields_str != "":
+            query_write(qpath, "query", qname, " {%s\\n\\t}" % fields_str, "a")
+        query_write(qpath, "query", qname, "\\n}\"}", "a")
         index += 1
     # --------------------
     # MUTATION
@@ -389,31 +389,34 @@ def generate(argument, custom=False, qpath="%s/%s", detect=True, green_print=lam
     index = 0
     for mname in m_name:
         print(" |  %s" % str(mname))
-        query_write(qpath, "mutation", mname, "{\"query\":\"mutation{%s(" % mname, "w")
-        for argsname in m_args_name[index]:
-            # POP out of the list empty values
-            if argsname != "":
-                # if detect type (-d param) is enabled, retrieve placeholders according to arg type
-                if detect:
-                    query_write(qpath, "mutation", mname,
-                               "%s:%s " % (argsname, detect_type(m_args_type.pop())), "a")
+        query_write(qpath, "mutation", mname, "{\"query\":\"mutation {\\n\\t%s" % mname, "w")
+        if len(m_args_name[index]) != 0:
+            arguments = []
+            for argsname in m_args_name[index]:
+                # POP out of the list empty values
+                if argsname != "":
+                    # if detect type (-d param) is enabled, retrieve placeholders according to arg type
+                    if detect:
+                        arguments.append("%s:%s" % (argsname, detect_type(m_args_type.pop())))
+                    else:
+                        arguments.append("%s:%s" % (argsname, m_args_type.pop()))
                 else:
-                    query_write(qpath, "mutation", mname,
-                               "%s:%s " % (argsname, m_args_type.pop()), "a")
-            else:
-                m_args_type.pop()
-        # Mutation name
-        query_write(qpath, "mutation", mname, "){", "a")
+                    m_args_type.pop()
+            # Mutation name
+            query_write(qpath, "mutation", mname, "(%s)" % " ".join(arguments), "a")
         # Mutation fields
+        fields_str = ""
         f_index = 0
         for fieldsnames in fields_names:
             if m_type[index] in fields_names[f_index][0]:
                 for items in fields_names[f_index][1:]:
-                    query_write(qpath, "mutation", mname, "\\n\\t%s " % items, "a")
+                    fields_str += "\\n\\t\\t%s " % items
                 break
             f_index += 1
         # Close mutation
-        query_write(qpath, "mutation", mname, "\\n}}\"}", "a")
+        if fields_str != "":
+            query_write(qpath, "mutation", mname, " {%s\\n\\t}" % fields_str, "a")
+        query_write(qpath, "mutation", mname, "\\n}\"}", "a")
         index += 1
     # --------------------
     # SUBSCRIPTION
@@ -422,32 +425,35 @@ def generate(argument, custom=False, qpath="%s/%s", detect=True, green_print=lam
     index = 0
     for sname in s_name:
         print(" |  %s" % str(sname))
-        query_write(qpath, "subscription", sname, "{\"query\":\"subscription{%s(" % sname,
+        query_write(qpath, "subscription", sname, "{\"query\":\"subscription {\\n\\t%s" % sname,
                    "w")
-        for argsname in s_args_name[index]:
-            # POP out of the list empty values
-            if argsname != "":
-                # if detect type (-d param) is enabled, retrieve placeholders according to arg type
-                if detect:
-                    query_write(qpath, "subscription", sname,
-                               "%s:%s " % (argsname, detect_type(s_args_type.pop())), "a")
+        if len(s_args_name[index]) != 0:
+            arguments = []
+            for argsname in s_args_name[index]:
+                # POP out of the list empty values
+                if argsname != "":
+                    # if detect type (-d param) is enabled, retrieve placeholders according to arg type
+                    if detect:
+                        arguments.append("%s:%s" % (argsname, detect_type(s_args_type.pop())))
+                    else:
+                        arguments.append("%s:%s" % (argsname, s_args_type.pop()))
                 else:
-                    query_write(qpath, "subscription", sname,
-                               "%s:%s " % (argsname, s_args_type.pop()), "a")
-            else:
-                s_args_type.pop()
-        # Subscription name
-        query_write(qpath, "subscription", sname, "){", "a")
+                    s_args_type.pop()
+            # Subscription name
+            query_write(qpath, "subscription", sname, "(%s)" % " ".join(arguments), "a")
         # Subscription fields
         f_index = 0
+        fields_str = ""
         for fieldsnames in fields_names:
             if s_type[index] in fields_names[f_index][0]:
                 for items in fields_names[f_index][1:]:
-                    query_write(qpath, "subscription", sname, "\\n\\t%s " % items, "a")
+                    fields_str += "\\n\\t\\t%s " % items
                 break
             f_index += 1
         # Close subscription
-        query_write(qpath, "subscription", sname, "\\n}}\"}", "a")
+        if fields_str != "":
+            query_write(qpath, "subscription", sname, " {%s\\n\\t}" % fields_str, "a")
+        query_write(qpath, "subscription", sname, "\\n}\"}", "a")
         index += 1
     # --------------------
     # THE END, they all lived happily ever after (hopefully)
